MskSegUtil
==========

A Python package for MSK segmentation and anaylsis utilities.

Installation
------------

MskSegUtil requires Python version >= 3.6.

Via ``pip``
*************

We recommend installing MskSegUtil through ``pip``::

    pip install msk_seg_util

Via ``conda``
*************

MskSegUtil can also be installed through ``conda``::

    conda install -c arjundd msk_seg_util
    # (required for statistics) pip install scikit-posthocs
    # (required for segmentation metrics) pip install medpy
    # (required for visualization) pip install opencv-python
